Documentation
¶
Overview ¶
operation a serializable operation that can be appended to IPFS log
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Operation ¶
type Operation interface {
// GetKey Gets a key if applicable (ie. key value stores)
GetKey() *string
// GetOperation Returns an operation name (ie. append, put, remove)
GetOperation() string
// GetValue Returns the operation payload
GetValue() []byte
// GetEntry Gets the underlying IPFS log Entry
GetEntry() ipfslog.Entry
// GetDocs Gets the list of documents
GetDocs() []OpDoc
// Marshal Serializes the operation
Marshal() ([]byte, error)
}
Operation Describe an CRDT operation
func NewOperation ¶
NewOperation Creates a new operation
func NewOperationWithDocuments ¶ added in v1.12.0
NewOperationWithDocuments Creates a new operation from a map of batched documents
Click to show internal directories.
Click to hide internal directories.